pub fn prepare_migration_parts(
file: &PlannedMigrationFile,
batches: Vec<RecordBatch>,
) -> Result<Vec<PreparedMigrationPart>>Expand description
Resolves identifiers and groups batches from one source file.
Errors
Returns an error when an identifier column is not string-like or a batch cannot be sliced or rebuilt with current identifier metadata.